@@ -43,6 +43,8 @@
 extern "C" {
 #endif
 
+#include <inttypes.h>
+
 /* Window manager routines */
 
 MAVAPI void mav_gfxWindowOpen(int id, int x, int y, int w, int h, char *name, char *disp, int wmp, int sb, int qb, int ms, int ab, int stenb, int desta, int *wret, int *hret);
@@ -98,7 +100,7 @@ MAVAPI void mav_gfxNormalizeSet(int v);
 MAVAPI void mav_gfxBackfaceCullSet(int v);
 MAVAPI int  mav_gfxBackfaceCullGet(void);
 MAVAPI void mav_gfxBufferReadSet(int buf);
-MAVAPI void mav_gfxPixelRead(int x, int y, int w, int h, unsigned long *d);
+MAVAPI void mav_gfxPixelRead(int x, int y, int w, int h, uint32_t *d);
 MAVAPI void mav_gfxPixelReadUByte(int x, int y, int w, int h, unsigned char *d);
 MAVAPI void mav_gfxPixelDraw(int w, int h, float *v);
 MAVAPI void mav_gfxViewPortSet(int x, int y, int w, int h);
