@@ -40,6 +40,7 @@
 #endif
 
 #include <stdio.h>
+#include <inttypes.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -141,9 +142,9 @@ typedef struct {
 } MAV_quaternion;
 
 typedef struct {
-  long sec;
-  long usec;
-  long cpu;
+  uint32_t sec;
+  uint32_t usec;
+  uint32_t cpu;
 } MAV_time;
 
 typedef struct {
@@ -260,7 +261,7 @@ typedef struct MAV_TEXTURE_STRUCT {
   int defined;
   int width;
   int height;
-  unsigned long *mem;
+  uint32_t *mem;
   char *filename;
   MAV_texEnvFn texEnv;
   int transparent;
@@ -268,7 +269,7 @@ typedef struct MAV_TEXTURE_STRUCT {
   int nmaps;
   int *xsize;
   int *ysize;
-  unsigned long **mipmap;
+  uint32_t **mipmap;
 } MAV_texture;
 
 typedef struct {
@@ -490,7 +491,7 @@ MAVAPI int  mav_paletteTextureSet(MAV_palette *p, int index, char *filename);
 MAVAPI void mav_paletteTextureAlphaSet(MAV_palette *p, int index, float a);
 MAVAPI void mav_paletteTextureColourAlphaSet(MAV_palette *p, int index, int r, int g, int b, float a);
 MAVAPI void mav_paletteTextureMipmappingSet(MAV_palette *p, int index, int v);
-MAVAPI int  mav_paletteTextureSetFromMem(MAV_palette *p, int index, int width, int height, unsigned long *mem);
+MAVAPI int  mav_paletteTextureSetFromMem(MAV_palette *p, int index, int width, int height, uint32_t *mem);
 MAVAPI int  mav_paletteTextureEnvSet(MAV_palette *p, int index, MAV_texEnvFn fn);
 MAVAPI void mav_texEnvDefault(MAV_texture *tex);
 MAVAPI void mav_texEnvClamp(MAV_texture *tex);
