@@ -274,7 +274,7 @@ void mav_gfxBufferReadSet(int buf)
 {
 }
 
-void mav_gfxPixelRead(int x, int y, int width, int height, unsigned long *mem)
+void mav_gfxPixelRead(int x, int y, int width, int height, uint32_t *mem)
 {
 }
 
