@@ -527,7 +527,8 @@ void mav_gfxTextureSet(MAV_texture *tex, MAV_texEnvFn pTexEnv)
     if (tex->nmaps!=0) {
       tex->xsize= (int *) mav_malloc(tex->nmaps*sizeof(int));
       tex->ysize= (int *) mav_malloc(tex->nmaps*sizeof(int));
-      tex->mipmap= (unsigned long **) mav_malloc(tex->nmaps*sizeof(unsigned long *));
+      /*tex->mipmap= (unsigned long **) mav_malloc(tex->nmaps*sizeof(unsigned long *));*/
+	  tex->mipmap= (uint32_t **) mav_malloc(tex->nmaps*sizeof(uint32_t *));
     }
 
     for (i=0; i<tex->nmaps; i++) {
@@ -536,7 +537,8 @@ void mav_gfxTextureSet(MAV_texture *tex, MAV_texEnvFn pTexEnv)
 
       tex->xsize[i]= width;
       tex->ysize[i]= height;
-      tex->mipmap[i]= (unsigned long *) mav_malloc(width*height*sizeof(unsigned long));
+      /*tex->mipmap[i]= (unsigned long *) mav_malloc(width*height*sizeof(unsigned long));*/
+	  tex->mipmap[i]= (uint32_t *) mav_malloc(width*height*sizeof(uint32_t));
 #ifdef WIN32
       gluScaleImage(GL_RGBA, tex->width, tex->height, GL_UNSIGNED_BYTE, tex->mem, width, height, GL_UNSIGNED_BYTE, tex->mipmap[i]);
 #else
@@ -642,7 +644,8 @@ void mav_gfxBufferReadSet(int buf)
   }
 }
 
-void mav_gfxPixelRead(int x, int y, int width, int height, unsigned long *mem)
+/*void mav_gfxPixelRead(int x, int y, int width, int height, unsigned long *mem)*/
+void mav_gfxPixelRead(int x, int y, int width, int height, uint32_t *mem)
 {
   float *fmem= mav_malloc(width*height*3*sizeof(float));
   int i,j=0;
