@@ -1,5 +1,5 @@
 /*
-   GNU Maverik - a system for managing display and interaction in 
+   GNU Maverik - a system for managing display and interaction in
               Virtual Environment applications.
    Copyright (C) 2008  Advanced Interfaces Group
 
@@ -22,8 +22,6 @@
    mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
         University of Manchester, Manchester, M13 9PL, UK
 */
-
-
 // These are the only bits of Maverik we need. Keep interface to window
 // manager as light as possible to make its easy for other implementation
 
@@ -40,10 +38,14 @@
 #define MAVAPI 
 #endif
 
+#include "qdesktopwidget.h"
+
 #ifdef __cplusplus
 extern "C" {
 #endif
-MAVAPI void mav_gfxWindowOpen(int id, int x, int y, int w, int h, char *name, char *disp, int wmp, int sb, int qb, int ms, int ab, int stenb, int desta, int *wret, int *hret);
+MAVAPI void mav_gfxWindowOpen(int id, int x, int y, int w, int h, char *name,
+							  char *disp, int wmp, int sb, int qb, int ms,
+							  int ab, int stenb, int desta, int *wret, int *hret);
 MAVAPI void mav_gfxWindowClose(int id);
 MAVAPI void mav_gfxWindowSet(int id);
 MAVAPI void mav_gfxWindowBuffersSwap(void);
@@ -69,14 +71,24 @@ void mav_frameFn4Add(MAV_frameFn fn, void *);
 #endif
 
 
+//Added by qt3to4:
+#include <QCloseEvent>
+#include <QMouseEvent>
+#include <QKeyEvent>
+#include <QEvent>
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <QApplication>
+#include <QList>
+#include <QCursor>
+#include <QGLWidget>
+/*old
 #include <qapplication.h>
 #include <qlist.h>
 #include <qcursor.h>
 #include <qgl.h>
-
+*/
 #define MAX_WINS  10 // Make sure the same or greater than equivalent in mav_kernel.h
 #define MAX_FONTS 10 // Same as above
 
@@ -132,6 +144,8 @@ typedef struct {
 
 class MAVLIB_qtGLWidget : public QGLWidget
 {
+	Q_OBJECT;
+}
 public:
 
   MAVLIB_qtGLWidget(const QGLFormat &, QWidget *, const char *);
@@ -179,10 +193,11 @@ MAVLIB_qtGLWidget::MAVLIB_qtGLWidget(const QGLFormat &f, QWidget *parent, const
   this->setAutoBufferSwap(FALSE);
 
   // Set keyboard focus policy
-  this->setFocusPolicy(QWidget::ClickFocus);
+  this->setFocusPolicy(Qt::ClickFocus);
 
   // Set window boarder caption
-  this->setCaption(name);
+  this->setWindowTitle(tr(name));
+  //this->setCaption(name);
 }
 
 MAVLIB_qtGLWidget::MAVLIB_qtGLWidget(const QGLFormat &f, QWidget *parent, const char *name, MAVLIB_qtGLWidget *share) : QGLWidget(f, parent, name, share)
@@ -191,7 +206,7 @@ MAVLIB_qtGLWidget::MAVLIB_qtGLWidget(const QGLFormat &f, QWidget *parent, const
   this->setAutoBufferSwap(FALSE);
 
   // Set window boarder caption
-  this->setCaption(name);
+  this->setWindowTitle (tr(name));
 }
 
 
@@ -249,7 +264,8 @@ void MAVLIB_qtGLWidget::mousePressEvent(QMouseEvent* event)
   // Add a press event
   this->dealWithButton(event, 0);
 
-#if (QT_VERSION>=300)
+//#if (QT_VERSION>=300)
+#if (QT_VERSION >= QT_VERSION_CHECK(4, 4, 0))
   // Tell Qt to accept this event
   event->accept();
 #endif
@@ -269,7 +285,8 @@ void MAVLIB_qtGLWidget::mouseReleaseEvent(QMouseEvent* event)
   // Add a release event
   this->dealWithButton(event, 1);
 
-#if (QT_VERSION>=300)
+//#if (QT_VERSION>=300)
+#if (QT_VERSION >= QT_VERSION_CHECK(4, 4, 0))
   // Tell Qt to accept this event
   event->accept();
 #endif
@@ -292,7 +309,8 @@ void MAVLIB_qtGLWidget::keyPressEvent(QKeyEvent* event)
     this->dealWithKey(event, 0);
   }
 
-#if (QT_VERSION>=300)
+//#if (QT_VERSION>=300)
+#if (QT_VERSION >= QT_VERSION_CHECK(4, 4, 0))
   // Tell Qt to accept this event
   event->accept();
 #endif
@@ -312,7 +330,8 @@ void MAVLIB_qtGLWidget::keyReleaseEvent(QKeyEvent* event)
   // Add a release event
   this->dealWithKey(event, 1);
 
-#if (QT_VERSION>=300)
+//#if (QT_VERSION>=300)
+#if (QT_VERSION >= QT_VERSION_CHECK(4, 4, 0))
   // Tell Qt to accept this event
   event->accept();
 #endif
@@ -381,13 +400,13 @@ void MAVLIB_qtGLWidget::dealWithButton(QMouseEvent *event, int pressrel)
   else if (event->button() & Qt::RightButton) info[6]= 3;
 
   // Any modifier keys?
-  if (event->state() & Qt::ShiftButton) info[7]= 1;
+  if (event->modifiers() & Qt::ShiftModifier) info[7]= 1;
   else info[7]= 0;
 
-  if (event->state() & Qt::ControlButton) info[8]= 1;
+  if (event->modifiers() & Qt::ControlModifier) info[8]= 1;
   else info[8]= 0;
 
-  if (event->state() & Qt::AltButton) info[9]= 1;
+  if (event->modifiers() & Qt::AltModifier) info[9]= 1;
   else info[9]= 0;
 
   // Add the event to the list
@@ -510,7 +529,7 @@ char *mav_gfxModuleID(void)
 void mavlib_qtUpdate(void *ignored)
 {
   // called once per frame to to Qt processing
-  if (::qApp) ::qApp->processEvents(0);
+  if (qApp) qApp->processEvents(0);
 }
 
 int mav_gfxModuleInit(void)
@@ -619,22 +638,26 @@ void mav_gfxWindowClose(int id)
 void mav_gfxWindowResGet(int *xres, int *yres)
 {
   // have we got an a QApplication?
-  if (::qApp == NULL) {
+  if (qApp == NULL) {
     *xres= 1280;
     *yres= 1024;
     return;
   }
 
   // fetch the desktop widget
-#if (QT_VERSION>=300)
-  QDesktopWidget* d= ::qApp->desktop();
+//#if (QT_VERSION>=300)
+#if (QT_VERSION >= QT_VERSION_CHECK(4, 4, 0))
+  QDesktopWidget* d= qApp->desktop();
 #else
-  QWidget* d= ::qApp->desktop();
+  QWidget* d= qApp->desktop();
 #endif
 
   // return desktop size
-  *xres= d->width();
-  *yres= d->height();
+	if (d->isVirtualDesktop()) {
+  		QRect r = d->screenGeometry();
+  	    *xres = r.width();
+  	    *yres = r.height();
+	}
 }
 
 
@@ -724,14 +747,14 @@ int mav_gfxWindowEventGet(int *info)
   if (MAVLIB_qtGLWidget::eventList->count()==0) return 0;
 
   // fetch the first item
-  MAVLIB_qtEvent *ev= MAVLIB_qtGLWidget::eventList->getFirst();
+  MAVLIB_qtEvent ev= MAVLIB_qtGLWidget::eventList->first();
 
   // Copy data
-  for (i=0; i<10; i++) info[i]= ev->info[i];
-  rv= ev->rv + (ev->info[0]<<8);
+  for (i=0; i<10; i++) info[i]= ev.info[i];
+  rv= ev.rv + (ev.info[0]<<8);
 
   // remove the event from the list
-  MAVLIB_qtGLWidget::eventList->removeRef(ev);
+  MAVLIB_qtGLWidget::eventList->removeLast(ev);
 
   return rv;
 }
@@ -748,10 +771,10 @@ int mav_gfxWindowEventPeek(void)
   if (MAVLIB_qtGLWidget::eventList->count()==0) return 0;
 
   // fetch the first item
-  MAVLIB_qtEvent *ev= MAVLIB_qtGLWidget::eventList->getFirst();
+  MAVLIB_qtEvent ev= MAVLIB_qtGLWidget::eventList->takeFirst();
 
   // return stuff
-  return ev->rv + (ev->info[0]<<8);
+  return ev.rv + (ev.info[0]<<8);
 }
 
 
@@ -772,13 +795,16 @@ int mav_gfx3DfxBoardSet(int bd)
 
 // Routine to open a window and an OpenGL context
 
-void mav_gfxWindowOpen(int id, int x, int y, int width, int height, char *nm, char *disp, int wmplacement, int sb, int qb, int ms, int ab, int stenb, int desta, int *wret, int *hret)
+void mav_gfxWindowOpen(int id, int x, int y, int width, int height,
+					   char *nm, char *disp, int wmplacement, int sb,
+					   int qb, int ms, int ab, int stenb, int desta,
+					   int *wret, int *hret)
 {
   // Cast to fetch the parent widget 
   QWidget *parent= (QWidget *) disp;
 
   //  Ensure Qt is running if no parent widget specified
-  if (!parent && !::qApp) { 
+  if (!parent && !qApp) {
     int argc= 0;
     char **argv= NULL;
     new QApplication(argc, argv);
