@@ -477,7 +477,7 @@ void mav_initialise(int *argc_p, char *argv[])
   FILE *f;
   int defaultInit=0;
   char buf[100];
-  char confname[]= ".maverikrc";
+  char confname[]= "/home/rosch/.maverikrc";
   char *defaultMod[]={"mav_gfxModuleInit",
                       "mav_callbacksModuleInit",
                       "mav_SMSModuleInit",
