@@ -38,7 +38,9 @@
 #ifndef MAV_SUNOS5
 #ifndef MAV_LINUX
 #ifndef WIN32
-int gettimeofday(struct timeval *tp, ...);
+int gettimeofday (struct timeval *__restrict __tv,
+				  __timezone_ptr_t __tz);
+/*int gettimeofday(struct timeval *tp, ...);*/
 #endif
 #else
 double drand48(void);
@@ -1329,7 +1331,7 @@ void mav_timerStop(MAV_timer *timer)
 void mav_timePrint(char *s, MAV_time time)
 {
   printf("%s", s);
-  printf("sec %li usec %li cpu %li\n", time.sec, time.usec, time.cpu);
+  printf("sec %d usec %d cpu %d\n", time.sec, time.usec, time.cpu);
 }
 
 
