@@ -460,14 +460,14 @@ void mav_paletteMaterialSet(MAV_palette *p, int index, float a1, float a2, float
 
 /* Routine to read a texture from a raw or ASCII PPM file */
 
-int mavlib_readPPM(char *filename, int *width, int *height, unsigned long **mem)
+int mavlib_readPPM(char *filename, int *width, int *height, uint32_t **mem)
 {
   FILE *file;
   float rf, gf, bf;
   int r, g, b, i, j, mv;
   char str[100];
   unsigned char *c;
-  unsigned long *map;
+  uint32_t *map;
   int bin=0;
 
 /* Open PPM file */
@@ -524,7 +524,7 @@ int mavlib_readPPM(char *filename, int *width, int *height, unsigned long **mem)
 
 /* Parse */
   
-  *mem=(unsigned long *) mav_malloc(*width**height*sizeof(unsigned long));
+  *mem=(uint32_t *) mav_malloc(*width**height*sizeof(uint32_t));
   map=*mem;
 
   for (i=*height-1; i>=0; i--) {
@@ -578,7 +578,7 @@ int mavlib_readPPM(char *filename, int *width, int *height, unsigned long **mem)
 #define PNG_BYTES_TO_CHECK 8
 #define MAV_TRANSPARENT 2
 
-int mavlib_readPNG(char *filename, int *width, int *height, unsigned long **mem)
+int mavlib_readPNG(char *filename, int *width, int *height, uint32_t **mem)
 {
   FILE *file;
   png_byte hdr[PNG_BYTES_TO_CHECK];
@@ -684,7 +684,7 @@ int mavlib_readPNG(char *filename, int *width, int *height, unsigned long **mem)
 
   /* allocate memory for the image */
 
-  *mem= (unsigned long *)mav_malloc(sizeof(unsigned long) * (*width) * (*height));
+  *mem= (uint32_t *)mav_malloc(sizeof(uint32_t) * (*width) * (*height));
   row_pointer= (png_bytep *)mav_malloc(sizeof(png_bytep) * (*height));
 
   for (row=0; row<(*height); row++)
@@ -1065,7 +1065,7 @@ void mav_paletteTextureMipmappingSet(MAV_palette *p, int index, int v)
 
 /* Routine to define a texture in a given palette (from mem) */
 
-int mavlib_paletteTextureSetFromMemSC(MAV_palette *p, int index, int width, int height, unsigned long *mem)
+int mavlib_paletteTextureSetFromMemSC(MAV_palette *p, int index, int width, int height, uint32_t *mem)
 {
   int rv= MAV_TRUE;
 
@@ -1107,7 +1107,7 @@ int mavlib_paletteTextureSetFromMemSC(MAV_palette *p, int index, int width, int
   return rv;
 }
 
-int mav_paletteTextureSetFromMem(MAV_palette *p, int index, int width, int height, unsigned long *mem)
+int mav_paletteTextureSetFromMem(MAV_palette *p, int index, int width, int height, uint32_t *mem)
 {
   int rv= MAV_TRUE;
 
@@ -1630,7 +1630,7 @@ int mavlib_defaultColours[][3]={
 };
 
 extern int mavlib_texNum;
-extern unsigned long mavlib_tex[][16384];
+extern uint32_t mavlib_tex[][16384];
 
 void mavlib_paletteDefaultValues(MAV_palette *p)
 {
