@@ -146,9 +146,11 @@ MAV_window *mav_windowNew(int x, int y, int width, int height, char *name, char
   mav_gfxWindowBuffersSwap();
 
   /* Sky blue is default background colour after an initial black clear buffers */
-  mav_windowBackgroundColourSet(win, 0.0, 0.5, 1.0);
+  /* beiHR Farbe geaendert von 0.0, 0.5, 1.0 */
+  	mav_windowBackgroundColourSet(win, 0.5, 0.5, 1.0);
 
-  if (orig_win) mav_windowSet(orig_win);
+  if (orig_win)
+	  mav_windowSet(orig_win);
 
   return win;
 }
